# 贡献者公约行为准则

## 我们的承诺

作为成员、贡献者和领导者，我们承诺使我们的社区参与成为一个无骚扰的体验，无论年龄、体型、可见或不可见的残疾、种族、性别特征、性别认同和表达、经验水平、教育程度、社会经济地位、国籍、个人外貌、种族、种姓、肤色、宗教或性取向。

我们承诺以有助于开放、欢迎、多样化、包容和健康的社区的方式行事和互动。

## 我们的标准

有助于我们社区积极环境的行为示例包括：

* 对他人表现出同理心和善意
* 尊重不同的意见、观点和经验
* 给予和优雅地接受建设性的反馈
* 承担责任并向受我们错误影响的人道歉，并从中学习
* 专注于不仅对我们个人最有利的事情，而是对整个社区最有利的事情

不可接受行为的示例包括：

* 使用性化的语言或图像，以及任何形式的性关注或挑逗
* 挑衅、侮辱或贬低的评论，以及个人或政治攻击
* 公开或私下的骚扰
* 未经明确许可发布他人的私人信息，例如物理地址或电子邮件地址
* 其他在专业环境中合理认为不适当的行为

## 执行责任

社区领导者有责任澄清和执行我们可接受行为的标准，并将对他们认为不适当、威胁、冒犯或有害的任何行为采取适当和公平的纠正措施。

社区领导者有权利和责任删除、编辑或拒绝与本行为准则不符的评论、提交、代码、wiki编辑、问题和其他贡献，并在适当时沟通修改决定的原因。

## 范围

本行为准则适用于所有社区空间内，并且在个人正式代表社区在公共空间时也适用。代表我们社区的示例包括使用官方电子邮件地址，通过官方社交媒体账户发布，或在在线或离线活动中担任指定代表。

## 执行

滥用、骚扰或其他不可接受行为的实例可以报告给负责执行的社区领导者，联系方式为 shovel@hscsec.cn。所有投诉将得到及时和公平的审查和调查。

所有社区领导者都有义务尊重任何事件报告者的隐私和安全。

## 执行指南

社区领导者将遵循这些社区影响指南来确定他们认为违反本行为准则的任何行为的后果：

### 1. 更正

**社区影响**：使用不当语言或其他被认为在社区中不专业或不受欢迎的行为。

**后果**：社区领导者的私人书面警告，提供关于违规性质的澄清和为什么行为不当的解释。可能会要求公开道歉。

### 2. 警告

**社区影响**：通过单一事件或一系列行动的违规行为。

**后果**：警告并附有继续行为的后果。在指定时间内不得与相关人员互动，包括未经请求的与执行行为准则的人互动。这包括避免在社区空间以及外部渠道（如社交媒体）中的互动。违反这些条款可能导致临时或永久禁令。

### 3. 临时禁令

**社区影响**：严重违反社区标准，包括持续的不当行为。

**后果**：在指定时间内禁止与社区进行任何形式的互动或公开交流。在此期间，不得与相关人员进行公开或私下互动，包括未经请求的与执行行为准则的人互动。违反这些条款可能导致永久禁令。

### 4. 永久禁令

**社区影响**：表现出违反社区标准的模式，包括持续的不当行为、骚扰个人或对某些群体的攻击或贬低。

**后果**：永久禁止与社区进行任何形式的公开互动。

## 归属

本行为准则改编自[贡献者公约][homepage]，版本2.1，可在[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1]查看。

社区影响指南的灵感来自[Mozilla的行为准则执行阶梯][Mozilla CoC]。

有关此行为准则的常见问题的答案，请参见[https://www.contributor-covenant.org/faq][FAQ]。翻译版本可在[https://www.contributor-covenant.org/translations][translations]查看。

[homepage]: https://www.contributor-covenant.org
[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
[Mozilla CoC]: https://github.com/mozilla/diversity
[FAQ]: https://www.contributor-covenant.org/faq
[translations]: https://www.contributor-covenant.org/translations